@@ -59,9 +59,9 @@ CONFIGFILE = CONFIGPATH / "config.rc"
 
 PREF_OPENER = 'opener'
 DEFAULT_OPENER = 'xdg-open'
-PREF_SIDECAR = 'preferred-sidecar-format'
-DEFAULT_SIDECARS = '.json'
 PREF_EXT_EDITOR = 'editor'
+PREF_HIST_SIZE = 'history-size'
+DEFAULT_HIST_SIZE = '1000'
 
 
 class Context:
@@ -105,8 +105,10 @@ class Application(cursedspace.Application):
         # the mapping is 'sequence of keys' to 'command'
         # command can be either of these:
         # - 'command', name of a command (to be resolved and executed as is)
-        # - '::command param1 param2', command with parameters to be executed as such
-        # - ':command param1', command to be filled into the command line and the user has to complete it
+        # - '::command param1 param2', command with parameters to be executed
+        #    as such
+        # - ':command param1', command to be filled into the command line and
+        #    the user has to complete it
         self.keys = [
             (ANY_SCOPE, ('q', ), ('close',)),
             (ANY_SCOPE, ('X', ), ('quit',)),
@@ -129,6 +131,7 @@ class Application(cursedspace.Application):
             (DocPanel.SCOPE, ('g', 'd'), ('details',)),
             (FilePanel.SCOPE, ('c', 'd'), (':cd',)),
             (FilePanel.SCOPE, ('d', 'D'), ('rm',)),
+            (FilePanel.SCOPE, ('a',), (':rename %n',)),
             (FilePanel.SCOPE, ('y', 'y'), ('copy',)),
             (FilePanel.SCOPE, ('y', 'a'), ('append',)),
             (FilePanel.SCOPE, ('!', ), (':shell',)),
@@ -183,8 +186,7 @@ class Application(cursedspace.Application):
         self.blocking_task = None
 
         conf = configparser.ConfigParser(interpolation=None)
-        conf.read_dict({ALL_SCOPE: {PREF_OPENER: DEFAULT_OPENER,
-                                    PREF_SIDECAR: DEFAULT_SIDECARS}})
+        conf.read_dict({ALL_SCOPE: {PREF_OPENER: DEFAULT_OPENER}})
         self.configuration = metaindex.configuration.BaseConfiguration(conf)
         utils.parse_ls_colors()
         utils.parse_ls_icons()
@@ -229,12 +231,12 @@ class Application(cursedspace.Application):
 
         self.metaindexconf = metaindex.configuration.load(args.metaindex_config)
         self.cache = MemoryCache(self.metaindexconf)
+        self.cache.start()
 
         configpath = pathlib.Path(args.config).expanduser().resolve()
         self.load_config_file(configpath)
 
     def main(self):
-        self.cache.start()
         self.command_input = None
         if len(self.start_locations) > 0:
             for location in self.start_locations:
@@ -288,11 +290,11 @@ class Application(cursedspace.Application):
 
             if key == Key.TIMEOUT:
                 timed_out = True
-            
+
             elif key == Key.RESIZE:
                 self.resize_panels()
                 self.paint()
-            
+
             elif self.blocking_task is not None:
                 self.blocking_task.handle_key(key)
 
@@ -323,8 +325,12 @@ class Application(cursedspace.Application):
                         if self.current_panel is not None:
                             self.current_panel.handle_key(seq)
                     elif commandname.startswith(':') and not commandname.startswith('::'):
-                        prefill = shlex.split(commandname[1:])
-                        prefill = shlex.join([prefill[0]] + sum([expand_part(self, part) for part in prefill[1:]], start=[]))
+                        rawprefill = shlex.split(commandname[1:])
+                        prefill = shlex.join([rawprefill[0]]
+                                             + sum([expand_part(self, part)
+                                                    for part in rawprefill[1:]], start=[]))
+                        if len(rawprefill) == 1:
+                            prefill += " "
                         self.execute_command("enter-command", prefill)
                     else:
                         args = None
@@ -350,13 +356,22 @@ class Application(cursedspace.Application):
         try:
             retval = super().run()
         except Exception as exc:
+            retval = -1
             stored_exc = exc
 
         self.cache.quit()
 
         try:
-            HISTORYFILE.write_text("\n".join([command for command in self.command_history
-                                                      if len(command.strip()) > 0]))
+            history_size = int(self.configuration.get(ALL_SCOPE,
+                                                      PREF_HIST_SIZE,
+                                                      DEFAULT_HIST_SIZE))
+        except ValueError:
+            history_size = int(DEFAULT_HIST_SIZE)
+
+        try:
+            HISTORYFILE.write_text("\n".join([command
+                                              for command in self.command_history[-1*history_size:]
+                                              if len(command.strip()) > 0]))
         except Exception as exc:
             logger.error(f"Could not write to the history file {HISTORYFILE}: {exc}")
 
@@ -884,100 +899,6 @@ class Application(cursedspace.Application):
 
         return value.replace('\0', '').strip()
 
-    def get_preferred_sidecar_stores(self):
-        """Returns a list of all available metadata stores, sorted by preference of the user"""
-        preferred = self.configuration.list(ALL_SCOPE, PREF_SIDECAR, DEFAULT_SIDECARS)
-        preferred = [stores.BY_SUFFIX[suffix] for suffix in preferred if suffix in stores.BY_SUFFIX]
-        return preferred \
-             + [store for store in stores.STORES if store not in preferred]
-
-    def get_editable_sidecar_file(self, filepath):
-        """Get the editable sidecar file path for this file
-
-        Returns a tuple (path, is_collection, store) with the pathlib.Path to the sidecar file
-        (which may or may not exist), a boolean whether or not the sidecar file is a collection
-        file, and the store module that can be used to read/write the metadata to this sidecar.
-
-        May return (None, False, None) in case there is no usable storage. In that case it will
-        write a message into the error log, too.
-        """
-        # find what type of metadata file should be used
-        sidecar = None
-        is_collection = None
-        all_stores = [(store, hasattr(store, 'store')) for store in self.get_preferred_sidecar_stores()]
-        usable_stores = [store for store, usable in all_stores if usable]
-        if len(usable_stores) == 0:
-            logger.error(f"No usable sidecar storage formats available")
-            return None, False, None
-
-        prefer_collection = False
-
-        # find existing sidecar file
-        for store, usable in all_stores:
-            location = filepath.parent / (filepath.stem + store.SUFFIX)
-            if location.is_file() and usable:
-                sidecar = location
-                break
-
-        # if there was none, find existing collection sidecar file
-        if sidecar is None:
-            for store, is_usable in all_stores:
-                for collection_name in self.collection_metadata:
-                    location = filepath.parent / (collection_name + store.SUFFIX)
-                    if location.is_file():
-                        if is_usable:
-                            sidecar = location
-                            is_collection = True
-                            break
-                        else:
-                            prefer_collection = True
-                if sidecar is not None:
-                    break
-        # still none? just take the first preferred sidecar store and create a sidecar file
-        if sidecar is None:
-            if prefer_collection:
-                sidecar_name = self.collection_metadata[0]
-                is_collection = True
-            else:
-                sidecar_name = filepath.stem
-            sidecar = filepath.parent / (sidecar_name + usable_stores[0].SUFFIX)
-
-        return sidecar, is_collection, stores.BY_SUFFIX[sidecar.suffix]
-
-    def determine_sidecar_file(self, filepath):
-        """Determines the most likely sidecar file for the given filepath
-
-        Returns tuple (pathlib.Path, collection) with the path to the sidecar file
-        and whether or not it is/should be a collection sidecar file.
-
-        CAVEAT: The path to the sidecar file may not exist!
-        """
-        candidate = None
-        preferred_sidecar_format = self.configuration.list(ALL_SCOPE,
-                                                           PREF_SIDECAR,
-                                                           DEFAULT_SIDECARS)
-        all_sidecar_formats = preferred_sidecar_format + [store.SUFFIX for store in stores.STORES]
-        # try direct sidecar files first
-        for suffix in all_sidecar_formats:
-            path = filepath.parent / (filepath.stem + suffix)
-
-            if candidate is None:
-                # remember the very first option for later in case we find no existing sidecar file
-                candidate = path
-            
-            if path.is_file():
-                return path, False
-
-        # try if there's a collection file
-        for suffix in all_sidecar_formats:
-            for stem in self.collection_metadata:
-                path = filepath.parent / (stem + suffix)
-                if path.is_file():
-                    return path, True
-
-        # Nothing there, let's just use the first candidate
-        return candidate, False
-
     @property
     def collection_metadata(self):
         return self.configuration.list('General', 'collection-metadata', 'metadata')
